digicert_express
----------------

This module is used to automate the installation of DigiCert SSL Certificates.

**PLEASE NOTE**: This project is "pre-release" and not complete. We have not yet released our *test* package. Also, this tool requires a DigiCert account that has the express install feature enabled. You will need to contact `DigiCert Customer Support`_ in order to use this tool.

*As this project is currently in alpha testing there may be bugs and we cannot currently guarantee your results. Use at your own risk.*

.. _DigiCert Customer Support: https://www.digicert.com/support/
